<template>
  <div>
    <a-dropdown :trigger="['click']">
      <button class="flex gap-1 btn normal-case btn-ghost p-1 text-primary hover:text-primary hover:bg-transparent btn-sm ant-dropdown-trigger">
        
        <svg width="15" height="15" viewBox="0 0 15 15" fill="none"
              xmlns="http://www.w3.org/2000/svg">
          <path
              d="M10.8333 6.66667V4.16667H8.33333V2.5H10.8333V0H12.5V2.5H15V4.16667H12.5V6.66667H10.8333ZM14.125 15C12.3333 15 10.5869 14.6006 8.88583 13.8017C7.18417 13.0033 5.67722 11.9478 4.365 10.635C3.05222 9.32278 1.99667 7.81583 1.19833 6.11417C0.399445 4.41306 0 2.66667 0 0.875C0 0.625 0.0833333 0.416667 0.25 0.25C0.416667 0.0833333 0.625 0 0.875 0H4.25C4.44444 0 4.61806 0.0624999 4.77083 0.1875C4.92361 0.3125 5.01389 0.472222 5.04167 0.666667L5.58333 3.58333C5.61111 3.77778 5.60778 3.95472 5.57333 4.11417C5.53833 4.27417 5.45833 4.41667 5.33333 4.54167L3.3125 6.58333C3.89583 7.58333 4.62861 8.52083 5.51083 9.39583C6.3925 10.2708 7.36111 11.0278 8.41667 11.6667L10.375 9.70833C10.5 9.58333 10.6633 9.48944 10.865 9.42667C11.0661 9.36444 11.2639 9.34722 11.4583 9.375L14.3333 9.95833C14.5278 10 14.6875 10.0936 14.8125 10.2392C14.9375 10.3853 15 10.5556 15 10.75V14.125C15 14.375 14.9167 14.5833 14.75 14.75C14.5833 14.9167 14.375 15 14.125 15ZM2.52083 5L3.89583 3.625L3.54167 1.66667H1.6875C1.75694 2.23611 1.85417 2.79861 1.97917 3.35417C2.10417 3.90972 2.28472 4.45833 2.52083 5ZM9.97917 12.4583C10.5208 12.6944 11.0731 12.8819 11.6358 13.0208C12.1981 13.1597 12.7639 13.25 13.3333 13.2917V11.4583L11.375 11.0625L9.97917 12.4583Z"
              fill="#7646FC"/>
        </svg>
        <span class="text-primary text-sm">{{
            general.currentRegisterPhone ?? ""
          }}</span>

        <svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
          <path d="M8.66665 10.6667L12 14L15.3333 10.6667" stroke="#7646FC" stroke-linecap="round" stroke-linejoin="round"/>
        </svg>
      </button>
      <template #overlay>
        <a-menu class="min-w-200 !bg-zinc-500" style="border-radius: 2rem!important;border-top-left-radius: 0px!important;padding:.6rem">
          <a-menu-item class="bg-zinc-500 hover:!bg-zinc-500 !text-neutral-400 !duration-0" disabled>Business ID - {{ currentPhoneNumber?.business_id }}</a-menu-item>
          
          <a-menu-item v-for="(phone, key) in listPhoneNumber" class="bg-zinc-500 hover:!bg-zinc-500 !text-white !duration-0">
            <button :class="`block w-full text-left py-1 px-2 ${currentPhoneNumber?.phone_number_id === phone.phone_number_id ? 'btn-disabled text-white bg-scheme-primary font-light rounded-md' : ''}`" @click="changePhoneNumber(phone.phone_number_id)">
              {{ phone.register_phone }} - {{phone?.verified_name}}
            </button>
          </a-menu-item>
        </a-menu>
      </template>
    </a-dropdown>
  </div>
</template>

<script setup lang="ts">
import {onMounted,ref,watch} from "vue";
import {useArrayFind} from "@vueuse/core";
import {useChatListStore} from "../../stores/chat_list";
import {useGeneralStore} from "../../stores/general";
import {useUserStore} from "../../stores/user";
import {useDashboardStore} from "../../stores/dashboard";

const chat = useChatListStore()
const general = useGeneralStore()
const user = useUserStore()
const dashboard = useDashboardStore()

const businessId = ref("")
const currentPhoneNumber = ref(null)
const listPhoneNumber = ref([])

const isResetFilter = ref(false)

const changePhoneNumber = async (phone_number_id) => {
  general.isShowProfile = false
  
  chat.selectedChat = null
  await user.setPhoneNumberId(businessId.value, phone_number_id)
  .then((resp) => {
    if (resp.code == 200) {
      resetLabelFilter()
      
      const findPhone = useArrayFind(listPhoneNumber.value, v => v.phone_number_id === resp.data.phone_number_id)
      
      general.currentPhoneNumber = findPhone.value.phone_number_id
      general.currentRegisterPhone = findPhone.value.register_phone
      currentPhoneNumber.value = findPhone
      chat.getUnreadCount()
      chat.fetchChatListByGroup(chat.tabName, true)
      chat.isEndPage = false
      chat.currentPage = 1

      dashboard.fetchVendorWaba()
      user.fetchDataChannel()
    }
  })
  .catch((err) => {

  })
}


const resetLabelFilter = () => {
  isResetFilter.value = true
  chat.isListFiltered = false
  chat.filterData.labels = []
  chat.filterData.agents = []
  chat.filterData.is_expired = 0
  chat.filterData.is_almost_expired = 0
  chat.filterData.is_waiting_reply = 0
  chat.filterData.is_meta = 0
  chat.filterData.is_tiktok = 0
  chat.filterData.start_date = ""
  chat.filterData.end_date = ""
  chat.filterData.sort = ""
  chat.filterData.name = ""
  chat.isLabelFiltered = false
  localStorage.setItem("filter_label", JSON.stringify([]))
  localStorage.setItem("filter_agent", JSON.stringify([]))
  chat.selectedLabel = []
  chat.fetchChatListByGroup(chat.tabName, true)
  chat.currentPage = 1
  chat.isEndPage = false
}

onMounted(async () => {
  if (user.listPhone && user.listPhone.length > 0) {
    let phones = []
    user.listPhone.map((item) => {
      businessId.value = item.business_id
      phones.push(item)
      if (item.is_active === 1) {
        currentPhoneNumber.value = item
        general.currentPhoneNumber = item.phone_number_id
        general.currentRegisterPhone = item.register_phone
      }
    })
    
    listPhoneNumber.value = phones
  }
})

watch(() => user.listPhone, (val) => {
  console.log('ini dia isi list phone nya',val)
  if (val && val.length > 0) {
    let phones = []
    val.map((item) => {
      businessId.value = item.business_id
      phones.push(item)
      if (item.is_active === 1) {
        currentPhoneNumber.value = item
        general.currentPhoneNumber = item.phone_number_id
        general.currentRegisterPhone = item.register_phone
      }
    })
    listPhoneNumber.value = phones
  }
})
</script>